@@ -58,11 +58,13 @@ mod test_readme {
 #[macro_use]
 extern crate alloc;
 
-pub use axgeom;
 
 #[doc(inline)]
 pub use broccoli_tree as tree;
 
+
+pub use tree::axgeom;
+
 use broccoli_tree::build::*;
 use broccoli_tree::node::*;
 use tree::*;
